@@ -326,7 +326,11 @@ void CDocBrowser::slotCopyText()
 void CDocBrowser::slotFindTextNext(QString str){
 
   kdDebug() << "CDocBrowser::slotFindTextNext !" << endl;
-  findTextNext(QRegExp(str), true);
+#if (QT_VERSION < 300)
+  findTextNext(QRegExp(str),true);
+#else
+  findTextNext(str,true,false,true);
+#endif
 }
 
 void CDocBrowser::slotSearchText(){
@@ -372,7 +376,7 @@ QString CDocBrowser::currentTitle(){
   return (m_refTitle.isEmpty()) ? m_title : m_refTitle+" - "+m_title;  
 }
 
-
+#if (QT_VERSION < 300)
 void  CDocBrowser::urlSelected ( const QString &url, int button, int state, const QString &_target)
 {
   KHTMLPart::urlSelected (url, button, state,_target);
@@ -380,6 +384,15 @@ void  CDocBrowser::urlSelected ( const QString &url, int button, int state, cons
   KURL cURL = completeURL( url );
   showURL( cURL.url() ) ;
 }
+#else
+void  CDocBrowser::urlSelected ( const QString &url, int button, int state, const QString &_target, KParts::URLArgs args)
+{
+  KHTMLPart::urlSelected (url, button, state,_target, args);
+
+  KURL cURL = completeURL( url );
+  showURL( cURL.url() ) ;
+}
+#endif
 
 void  CDocBrowser::doSearchDialog()
 {
