@@ -35,12 +35,15 @@
 #include <qwhatsthis.h>
 #include <qlayout.h>
 #include <qgrid.h>
+#include <qvbox.h>
+#include <qvbuttongroup.h>
+#include <qradiobutton.h>
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-CKDevSetupDlg::CKDevSetupDlg(KAccel* accel, QWidget *parent, const char *name ) :
+CKDevSetupDlg::CKDevSetupDlg(KAccel* accel, QWidget *parent, const char *name, int mdiMode ) :
   KDialogBase ( IconList,                 // dialogFace
                 i18n("KDevelop Setup"),   // caption
                 Ok|Default|Cancel,        // buttonMask
@@ -48,10 +51,11 @@ CKDevSetupDlg::CKDevSetupDlg(KAccel* accel, QWidget *parent, const char *name )
                 parent,
                 name,
                 true,                     // modal
-                true),                    // separator
-  wantsTreeRefresh(false),
-  config(KGlobal::config()),
-  m_accel(accel)
+                true)                     // separator
+  ,wantsTreeRefresh(false)
+  ,config(KGlobal::config())
+  ,m_accel(accel)
+	,m_mdiMode(mdiMode)
 {
 
   addGeneralTab();
@@ -59,6 +63,7 @@ CKDevSetupDlg::CKDevSetupDlg(KAccel* accel, QWidget *parent, const char *name )
   addDocTab();
   addDebuggerTab();
   addQT2Tab();
+  addUserInterfaceTab();
 
 //  connect( this, SIGNAL(defaultButtonPressed()), SLOT(slotDefault()) );
   connect( this, SIGNAL(okClicked()), SLOT(slotOkClicked()) );
@@ -252,9 +257,8 @@ void CKDevSetupDlg::addGeneralTab()
                     "the last project used."));
 
 
-  config->setGroup("TipOfTheDay");
-  bool tip=config->readBoolEntry("show_tod",true);
-
+  config->setGroup("TipOfDay");
+  bool tip=config->readBoolEntry("RunOnStart",true);
 
 	tipDayCheck = new QCheckBox( startupGroup, "tipDayCheck" );
                 grid2->addWidget(tipDayCheck,0,1);
@@ -384,7 +388,7 @@ void CKDevSetupDlg::addDocTab()
   docOptionsGroup->setFrameStyle( 49 );
   docOptionsGroup->setTitle(i18n("Options"));
   docOptionsGroup->setAlignment( 1 );
-  grid2 = new QGridLayout(docOptionsGroup,3,2,15,7);
+  grid2 = new QGridLayout(docOptionsGroup,4,2,15,7);
   QLabel* update_label;
   update_label = new QLabel( docOptionsGroup, "update_label" );
   grid2->addWidget(update_label,0,0);
@@ -439,8 +443,33 @@ void CKDevSetupDlg::addDocTab()
   QWhatsThis::add(create_label, createMsg);
   QWhatsThis::add(create_button, createMsg);
 
+
+  useCTags = new QCheckBox( docOptionsGroup, "useCTags" );
+  grid2->addWidget(useCTags,2,0);
+  useCTags->setText(i18n("Enable CTags database"));
+  useCTags->setAutoRepeat( FALSE );
+  useCTags->setAutoResize( FALSE );
+  bool bUseCTags;
+  config->setGroup("General Options");
+  bUseCTags = config->readBoolEntry("use_ctags", false);
+  useCTags->setChecked( bUseCTags );
+  QWhatsThis::add(useCTags,
+    i18n("Enable CTags based browsing and searching.\n\n"
+         "If this is enabled, you can browse the source code of your"
+         "project much easier. You can jump to declarations"
+         "and definitions of functions, classes and methods"
+         "using the right mouse button.\n"));
+
+  QPushButton* load_ctags_button;
+  load_ctags_button = new QPushButton( docOptionsGroup, "load_ctags_button" );
+  grid2->addWidget(load_ctags_button,2,1);
+  connect( load_ctags_button, SIGNAL(clicked()),parent(), SLOT(slotProjectLoadTags()) );
+  load_ctags_button->setText(i18n("Load"));
+  load_ctags_button->setAutoRepeat( FALSE );
+  load_ctags_button->setAutoResize( FALSE );
+
   kdocCheck = new QCheckBox( docOptionsGroup, "kdocCheck" );
-  grid2->addWidget(kdocCheck,2,0);
+  grid2->addWidget(kdocCheck,3,0);
   kdocCheck->setText(i18n("Create also KDOC-reference of your project"));
   kdocCheck->setAutoRepeat( FALSE );
   kdocCheck->setAutoResize( FALSE );
@@ -677,6 +706,77 @@ void CKDevSetupDlg::addQT2Tab()
   QWhatsThis::add(ppath, ppathMsg);
 }
 
+//
+//************************** QT-2 directory select *************************
+//
+void CKDevSetupDlg::addUserInterfaceTab()
+{
+  QFrame* UserInterfacePage = addPage(i18n("User interface"),i18n("Type of user interface"),
+  KGlobal::instance()->iconLoader()->loadIcon( "window_list", KIcon::NoGroup, KIcon::SizeMedium ));
+
+  QGridLayout* grid = new QGridLayout(UserInterfacePage,3,1,15,7);
+  QLabel* label = new QLabel(i18n("What kind of user interface do you want?"),UserInterfacePage);
+  grid->addWidget(label,0,0);
+
+  bg = new QButtonGroup(UserInterfacePage);
+  grid->addWidget(bg,1,0);
+  QGridLayout* innerGrid = new QGridLayout(bg,3,2,15,7);
+  QPixmap pm;
+
+  QRadioButton* childframe = new QRadioButton( i18n("Childframe Mode"), bg );
+  innerGrid->addWidget(childframe,0,0);
+  QLabel* pictureLabelCF = new QLabel(bg);
+  pm.load(locate("appdata", "pics/childfrm.png"));
+  pictureLabelCF->setPixmap(pm);
+  innerGrid->addWidget(pictureLabelCF,0,1);
+
+  QRadioButton* toplevel = new QRadioButton( i18n("Toplevel Mode"), bg );
+  innerGrid->addWidget(toplevel,1,0);
+  QLabel* pictureLabelTL = new QLabel(bg);
+  pm.load(locate("appdata", "pics/toplevel.png"));
+  pictureLabelTL->setPixmap(pm);
+  innerGrid->addWidget(pictureLabelTL,1,1);
+
+  QRadioButton* tabpage = new QRadioButton( i18n("Tab Page Mode"), bg );
+  innerGrid->addWidget(tabpage,2,0);
+  QLabel* pictureLabelTP = new QLabel(bg);
+  pm.load(locate("appdata", "pics/tabpage.png"));
+  pictureLabelTP->setPixmap(pm);
+  innerGrid->addWidget(pictureLabelTP,2,1);
+
+  childframe->setChecked(false);
+  toplevel->setChecked(false);
+  tabpage->setChecked(false);
+//  tabpage->setEnabled(false);//until it is usuable
+
+  switch (m_mdiMode) {
+  case QextMdi::ToplevelMode:
+    toplevel->setChecked(true);
+    break;
+  case QextMdi::ChildframeMode:
+    childframe->setChecked(true);
+    break;
+  case QextMdi::TabPageMode:
+    tabpage->setChecked(true);
+    break;
+  default:
+    break;
+  }
+
+  bg->setFrameStyle(QFrame::Raised|QFrame::Box);
+  bg->setMargin(8);
+  bg->setFixedHeight(bg->sizeHint().height());
+
+  grid->setRowStretch(2,1);
+
+  QString cfTxt = i18n("All tool views are initially docked to the mainframe.\nEditor and browser views will live within a view area of the mainframe.");
+  QWhatsThis::add(childframe, cfTxt);
+  QString tlTxt = i18n("All editor, browser and tool views will be toplevel windows (directly on desktop).");
+  QWhatsThis::add(toplevel, tlTxt);
+  QString tpTxt = i18n("All tool views are initially docked to the mainframe.\nEditor and browser views will be stacked in a tab window.");
+  QWhatsThis::add(tabpage, tpTxt);
+}
+
 void CKDevSetupDlg::slotDefault(){
 
   // General tab
@@ -786,11 +886,14 @@ void CKDevSetupDlg::slotOkClicked(){
   bool kdoc=kdocCheck->isChecked();
   config->writeEntry("CreateKDoc",kdoc);
 
+  bool bCTags=useCTags->isChecked();
+  config->writeEntry("use_ctags",bCTags);
+
   bool lastprj=lastProjectCheck->isChecked();
   config->writeEntry("LastProject",lastprj);
 	
-	config->setGroup("TipOfTheDay");
-  config->writeEntry("show_tod",tipDayCheck->isChecked());
+	config->setGroup("TipOfDay");
+    config->writeEntry("RunOnStart",tipDayCheck->isChecked());
 
   config->setGroup("Debug");
   config->writeEntry("Use external debugger", dbgExternalCheck->isChecked());
@@ -810,6 +913,22 @@ void CKDevSetupDlg::slotOkClicked(){
   config->writeEntry("ProjectDefaultDir", ppath_edit->text());	
 // ---
 
+  // user interface
+  config->setGroup("General Options");
+  switch (bg->id(bg->selected())) {
+  case 0:
+	  m_mdiMode = QextMdi::ChildframeMode;
+    break;
+  case 1:
+	  m_mdiMode = QextMdi::ToplevelMode;
+    break;
+  case 2:
+	  m_mdiMode = QextMdi::TabPageMode;
+    break;
+  default:
+    break;
+  }
+
   m_accel->setKeyDict(keyMap);
   m_accel->writeSettings(config);
   config->sync();
@@ -928,4 +1047,5 @@ void CKDevSetupDlg::slotPPathClicked(){
   }
 }
 // ---
+
 #include "ckdevsetupdlg.moc"
