@@ -19,6 +19,7 @@
 
 #include <kiconloader.h>
 #include <kstddirs.h>
+#include <kdebug.h>
 
 #include <qlist.h>
 #include <qlistview.h>
@@ -261,6 +262,43 @@ QListViewItem *CTreeHandler::addItem( const char *aName,
   return item;
 }
 
+//-----------------------------------------------------------------
+QStringList CTreeHandler::pathListOfAllOpenedItems()
+{
+  QStringList list;
+  if (!tree)
+    return list;
+
+  QListViewItem *pCurItem = tree->firstChild();
+  appendOpenedItemsOfSubtreeToPathList( &list, pCurItem);
+  list.sort();
+  return list;
+}
+
+//-----------------------------------------------------------------
+QString CTreeHandler::pathToSelectedItem()
+{
+  if (!tree) return "";
+  QListViewItem *item = tree->currentItem(); // the currently selected one
+  return pathToItem(item);
+}
+
+//-----------------------------------------------------------------
+void CTreeHandler::openItems(QStringList pathList)
+{
+  for (QStringList::Iterator it = pathList.begin(); it != pathList.end(); ++it ) {
+    QString curPath = *it;
+    kdDebug() << "reopen: " << curPath << endl;
+    goToItem( curPath, true, false);
+  }
+}
+
+//-----------------------------------------------------------------
+void CTreeHandler::activateItem(const char* path)
+{
+  goToItem( path, false, true);
+}
+
 /*********************************************************************
  *                                                                   *
  *                          PRIVATE METHODS                          *
@@ -269,7 +307,7 @@ QListViewItem *CTreeHandler::addItem( const char *aName,
 
 /*------------------------------------ CClassTreeHandler::readIcons()
  * readIcons()
- *   Read the icons from disk and store them in the class.
+ *   Read the icons from dactivateItemisk and store them in the class.
  *
  * Parameters:
  *   -
@@ -312,4 +350,83 @@ void CTreeHandler::readIcons()
   iconsRead = true;
 }
 
+//-----------------------------------------------------------------
+void CTreeHandler::appendOpenedItemsOfSubtreeToPathList(QStringList *pList, QListViewItem *pCurItem)
+{
+  while (pCurItem) {
+    if (pCurItem->isOpen()) {
+      pList->append(pathToItem(pCurItem));
+      // recursive check of the children
+      QListViewItem* pFirstChild = pCurItem->firstChild();
+      appendOpenedItemsOfSubtreeToPathList( pList, pFirstChild);
+    }
+    pCurItem = pCurItem->nextSibling();
+  }
+}
 
+//-----------------------------------------------------------------
+QString CTreeHandler::pathToItem(QListViewItem* pItem)
+{
+  QString path;
+  if (pItem) {
+    path = pItem->text(0);
+    pItem = pItem->parent();
+  }
+  while (pItem) {
+    path = pItem->text(0) + "*" + path; // "*" is the separator
+    pItem = pItem->parent();
+  }
+  return path;
+}
+
+//-----------------------------------------------------------------
+void CTreeHandler::goToItem(const char* path, bool bAction_OpenTheItem, bool bAction_SelectTheItem)
+{
+  if (!tree) return;
+
+  QString p = path;
+  QString curItemText;
+  QListViewItem *pCurItem = tree->firstChild();
+  int pos = p.find("*");
+
+  // go along the path and expand the appropriate tree branches
+  while (pCurItem) {
+    if (pos != -1) {
+      curItemText = p.left(pos);
+    }
+    else {
+      curItemText = p;
+    }
+
+    // try to find the right item in the current level
+    bool bReachedEnd = false;
+    QListViewItem* pCandidate = pCurItem;
+    while (!bReachedEnd && (pCandidate->text(0) != curItemText)) {
+      pCandidate = pCandidate->nextSibling();
+      if (!pCandidate) {
+        bReachedEnd = true;
+      }
+    }
+    if (!bReachedEnd) {
+      // has found this part of the path,
+      // if possible and desired, expand the tree here.
+      if (pCandidate->firstChild()) {
+        if (bAction_OpenTheItem) {
+          pCandidate->setOpen(true);
+        }
+      }
+      // if desired and the path is completely processed, highlight the item
+      if (bAction_SelectTheItem && (p == curItemText)) {
+        tree->setSelected( pCandidate, true);
+      }
+      // prepare to enter the next subtree
+      pCurItem = pCandidate->firstChild();
+
+    }
+    else {
+      pCurItem = 0L;
+    }
+    p = p.right(p.length() - pos - 1);
+    pos = p.find("*");
+  }
+}
