@@ -1,9 +1,11 @@
 #ifndef _KWVIEV_H_
 #define _KWVIEV_H_
 
+#include <qpoint.h>
+
 #include <qscrbar.h>
 #include <qiodev.h>
-#include <kpopupmenu.h>
+#include <kpopupmenu.h>                  	
 #include <kconfig.h>
 
 #include "kwdialog.h"
@@ -34,26 +36,27 @@ const int srAll             = 11;
 const int srCancel          = QDialog::Rejected;
 
 //config flags
-const int cfAutoIndent      = 1;
-const int cfBackspaceIndent = 2;
-const int cfWordWrap        = 4;
-const int cfReplaceTabs     = 8;
-const int cfRemoveSpaces    = 16;
-const int cfWrapCursor      = 32;
-const int cfAutoBrackets    = 64;
+const int cfAutoIndent        = 1;
+const int cfBackspaceIndent   = 2;
+const int cfWordWrap          = 4;
+const int cfReplaceTabs       = 8;
+const int cfRemoveSpaces      = 16;
+const int cfWrapCursor        = 32;
+const int cfAutoBrackets      = 64;
 
-const int cfPersistent      = 128;
-const int cfKeepSelection   = 256;
-const int cfVerticalSelect  = 512;
-const int cfDelOnInput      = 1024;
-const int cfXorSelect       = 2048;
+const int cfPersistent        = 128;
+const int cfKeepSelection     = 256;
+const int cfVerticalSelect    = 512;
+const int cfDelOnInput        = 1024;
+const int cfXorSelect         = 2048;
 
-const int cfOvr             = 4096;
-const int cfMark            = 8192;
+const int cfOvr               = 4096;
+const int cfMark              = 8192;
 
-const int cfAutoCopy        = 16384;
+const int cfAutoCopy          = 16384;
 
-const int cfShowTabs    		= 32768;
+const int cfShowTabs          = 32768;
+const int cfHighlightBrackets = 65536;
 
 
 //update flags
@@ -78,6 +81,12 @@ struct PointStruc {
   int y;
 };
 
+struct BracketMark {
+  PointStruc cursor;
+  int sXPos;
+  int eXPos;
+};
+
 struct VConfig {
   PointStruc cursor;
   int flags;
@@ -90,6 +99,8 @@ struct SConfig {
   int flags;
 };
 
+extern int kw_bookmark_keys[];
+
 class KWrite;
 class KWriteView;
 
@@ -99,29 +110,29 @@ class KIconBorder : public QWidget {
     KIconBorder(KWrite *, KWriteDoc *, KWriteView *);
     ~KIconBorder();
 
-  	/** Paints line */
-		void paintLine(int line);
-		/** Clear line*/
-		void clearLine(int line);
-		/** Clear the icon border */
-		void clearAll();
-		/** Paint a bookmark on the line if needed */
-		void paintBookmark(int line);
-		/** Paint a breakpoint on the line if needed */
-		void paintBreakpoint(int line);
+    /** Paints line */
+    void paintLine(int line);
+    /** Clear line*/
+    void clearLine(int line);
+    /** Clear the icon border */
+    void clearAll();
+    /** Paint a bookmark on the line if needed */
+    void paintBookmark(int line);
+    /** Paint a breakpoint on the line if needed */
+    void paintBreakpoint(int line);
     /** Painst an icon where the debugger has stopped */
     void paintDbgPosition(int line);
 
-  	/**  */
-  	virtual void mousePressEvent(QMouseEvent* e);
-  	/**  */
+    /**  */
+    virtual void mousePressEvent(QMouseEvent* e);
+    /**  */
     virtual void paintEvent(QPaintEvent* e);
 
 protected:
-		/** Clear some pixel lines */
-		void clearPixelLines(int startPixelLine, int numberPixelLine);
-  	/** Paint an icon to y */
-		void showIcon(const QPixmap& icon, int y);
+    /** Clear some pixel lines */
+    void clearPixelLines(int startPixelLine, int numberPixelLine);
+    /** Paint an icon to y */
+    void showIcon(const QPixmap& icon, int y);
 
   protected slots:
     /**  */
@@ -138,25 +149,25 @@ protected:
   private:
     KWrite *kWrite;
     KWriteDoc *kWriteDoc;
-		KWriteView *kWriteView;
+    KWriteView *kWriteView;
 
-		KPopupMenu selectMenu;
-		/** action when user left clicks in border */
-  	bool LMBIsBreakpoint;
+    KPopupMenu selectMenu;
+    /** action when user left clicks in border */
+    bool LMBIsBreakpoint;
     /** cursor is on line number */
-	  int cursorOnLine;
-	  /** the checkable menu items */
-  	int menuId_LMBBrkpoint;
-	  int menuId_LMBBookmark;
-	  int menuId_editBrkpoint;
+    int cursorOnLine;
+    /** the checkable menu items */
+    int menuId_LMBBrkpoint;
+    int menuId_LMBBookmark;
+    int menuId_editBrkpoint;
     int menuId_enableBrkpoint;
 };
 
 class KWriteView : public QWidget {
     Q_OBJECT
-    friend KWriteDoc;
-    friend KWrite;
-    friend KIconBorder;
+    friend class KWriteDoc;
+    friend class KWrite;
+    friend class KIconBorder;
   public:
     KWriteView(KWrite *, KWriteDoc *);
     ~KWriteView();
@@ -174,9 +185,10 @@ class KWriteView : public QWidget {
     void top(VConfig &);
     void bottom(VConfig &);
 
-   	int getXPos() { return xPos;}
-  	int getYPos() { return yPos;}
-  	int getRange(int midline);
+    int getXPos() { return xPos;}
+    int getYPos() { return yPos;}
+    int getRange(int midline);
+    QPoint cursorPosition() { return QPoint(cursor.x, cursor.y); };
 
 protected slots:
     void changeXPos(int);
@@ -185,6 +197,8 @@ protected slots:
   protected:
     virtual bool event ( QEvent * );
 
+    void paintBracketMark();
+
     void getVConfig(VConfig &);
     void update(VConfig &);
 //    void updateCursor(PointStruc &start, PointStruc &end, bool insert);
@@ -193,6 +207,7 @@ protected slots:
     void updateCursor();
     void updateCursor(PointStruc &newCursor);
     void updateView(int flags, int newXPos = 0, int newYPos = 0);
+    void scroll(int, int);
 //  void scroll2(int, int);
     void wheelEvent(QWheelEvent *);
     void tagLines(int start, int end);
@@ -213,13 +228,14 @@ protected slots:
     virtual void paintEvent(QPaintEvent *);
     virtual void resizeEvent(QResizeEvent *);
     virtual void timerEvent(QTimerEvent *);
+    virtual bool focusNextPrevChild( bool next);
 
     KWrite *kWrite;
     KWriteDoc *kWriteDoc;
     QScrollBar *xScroll;
     QScrollBar *yScroll;
 	
-	KIconBorder *leftBorder;
+    KIconBorder *leftBorder;
 
     int xPos;
     int yPos;
@@ -230,6 +246,8 @@ protected slots:
     int scrollY;
     int scrollTimer;
 
+    BracketMark bm;
+
     PointStruc cursor;
     bool cursorOn;
     int cursorTimer;
@@ -241,8 +259,10 @@ protected slots:
     int endLine;
     int updateState;
     int updateLines[2];
+    bool bIsPainting;
 
     QPixmap *drawBuffer;
+	  bool m_hasFocus;
 };
 
 /*
@@ -263,9 +283,9 @@ class KWBookmark {
 
 class KWrite : public QWidget {
     Q_OBJECT
-    friend KWriteView;
-    friend KWriteDoc;
-		friend KIconBorder;
+    friend class KWriteView;
+    friend class KWriteDoc;
+    friend class KIconBorder;
   public:
     /** The document can be used by more than one KWrite objects
     */
@@ -338,6 +358,10 @@ class KWrite : public QWidget {
 
     /**  */
     void slotToggleBreakpoint();
+    /**  */
+    void pasteStr(QString s);
+    /**  */
+    void delMarkedText();
 
   signals:
     /** The cursor position has changed. Get the values with currentLine()
@@ -580,13 +604,13 @@ public slots:
     void toggleBookmark();
     /** Toggle a bookmark at line
     */
-		void toggleBookmark(int line);
+    void toggleBookmark(int line);
     /** Go to the next bookmark
     */
-		void nextBookmark();
+    void nextBookmark();
     /** Go to the previous bookmark
     */
-		void previousBookmark();
+    void previousBookmark();
     /** Clears all bookmarks
     */
     void clearBookmarks();
